Learn R Programming

CRF (version 0.3-8)

sub.crf: Make sub CRF

Description

Generate sub CRF by selecting some nodes

Usage

sub.crf(crf, subset)

Arguments

crf
The CRF generated by make.crf
subset
The vector of selected node ids

Value

  • The function will return a new CRF with additional components:
  • originalThe original CRF data.
  • node.idThe vector of the original node ids for nodes in the new CRF.
  • node.mapThe vector of the new node ids for nodes in the original CRF.
  • edge.idThe vector of the original edge ids for edges in the new CRF.
  • edge.mapThe vector of the new edge ids for edges in the original CRF.

Details

The function will generate a new CRF from a given CRF by selecting some nodes. The vector subset contains the node ids selected to generate the new CRF. Unlike clamp.crf, the potentials of remainning nodes and edges are untouched.

See Also

make.crf, clamp.crf

Examples

Run this code
library(CRF)
data(Small)
crf <- sub.crf(Small$crf, c(2, 3))

Run the code above in your browser using DataLab