The function will return a new CRF with additional components:
originalThe original CRF data.
node.idThe vector of the original node ids for nodes in the new CRF.
node.mapThe vector of the new node ids for nodes in the original CRF.
edge.idThe vector of the original edge ids for edges in the new CRF.
edge.mapThe vector of the new edge ids for edges in the original CRF.
Details
The function will generate a new CRF from a given CRF
by selecting some nodes. The vector subset contains the
node ids selected to generate the new CRF. Unlike
clamp.crf, the potentials of remainning nodes and edges are
untouched.