train.crf(crf, instances, node.fea = NaN, edge.fea = NaN, node.ext = NaN,
edge.ext = NaN, nll = crf.nll, trace = 0)In the training data matrix instances, each row is
an instance and each column corresponds a node in CRF. The
variables node.fea, edge.fea,
node.ext, edge.ext are lists of length equal
to the number of instances, and their elements are defined
as in crf.update respectively.
crf.update, crf.nll,
make.crf